@@ -9,46 +9,45 @@ from .exceptions import InvalidParams
 
 
 class AbstractBucket(ABC):
-    """Documentation for AbstractBucket
+    """Documentation for AbstractBucket"""
 
-    """
     def __init__(self, maxsize=0, **_kwargs):
         self._maxsize = maxsize
 
     def maxsize(self) -> int:
-        """ Return the maximum size of the bucket,
+        """Return the maximum size of the bucket,
         ie the maxinum number of item this bucket can hold
         """
         return self._maxsize
 
     @abstractmethod
     def size(self) -> int:
-        """ Return the current size of the bucket,
+        """Return the current size of the bucket,
         ie the count of all items currently in the bucket
         """
 
     @abstractmethod
     def put(self, item) -> int:
-        """ Putting an item in the bucket
+        """Putting an item in the bucket
         Return 1 if successful, else 0
         """
 
     @abstractmethod
     def get(self, number: int) -> int:
-        """ Get items and remove them from the bucket in the FIFO fashion
+        """Get items and remove them from the bucket in the FIFO fashion
         Return the number of items that have been removed
         """
 
     @abstractmethod
     def all_items(self) -> List[int]:
-        """ Return a list as copies of all items in the bucket
-        """
+        """Return a list as copies of all items in the bucket"""
 
 
 class MemoryQueueBucket(AbstractBucket):
-    """ A bucket that resides in memory
+    """A bucket that resides in memory
     using python's built-in Queue class
     """
+
     def __init__(self, maxsize=0, **_kwargs):
         super(MemoryQueueBucket, self).__init__()
         self._q = Queue(maxsize=maxsize)
@@ -72,9 +71,10 @@ class MemoryQueueBucket(AbstractBucket):
 
 
 class MemoryListBucket(AbstractBucket):
-    """ A bucket that resides in memory
+    """A bucket that resides in memory
     using python's List
     """
+
     def __init__(self, maxsize=0, **_kwargs):
         super(MemoryListBucket, self).__init__(maxsize=maxsize)
         self._q = []
@@ -104,9 +104,10 @@ class MemoryListBucket(AbstractBucket):
 
 
 class RedisBucket(AbstractBucket):
-    """ A bucket with Redis
+    """A bucket with Redis
     using List
     """
+
     def __init__(
         self,
         maxsize=0,
@@ -118,21 +119,20 @@ class RedisBucket(AbstractBucket):
         super(RedisBucket, self).__init__(maxsize=maxsize)
 
         if not bucket_name or not isinstance(bucket_name, str):
-            msg = 'keyword argument bucket-name is missing: a distict name is required'
+            msg = "keyword argument bucket-name is missing: a distict name is required"
             raise InvalidParams(msg)
 
         self._pool = redis_pool
-        self._bucket_name = f'{bucket_name}___{identity}'
+        self._bucket_name = f"{bucket_name}___{identity}"
 
     def get_connection(self):
-        """ Obtain a connection from redis pool
-        """
+        """Obtain a connection from redis pool"""
         from redis import Redis
+
         return Redis(connection_pool=self._pool)
 
     def get_pipeline(self):
-        """ Using redis pipeline for batch operation
-        """
+        """Using redis pipeline for batch operation"""
         conn = self.get_connection()
         pipeline = conn.pipeline()
         return pipeline
@@ -165,4 +165,4 @@ class RedisBucket(AbstractBucket):
     def all_items(self):
         conn = self.get_connection()
         items = conn.lrange(self._bucket_name, 0, -1)
-        return [int(i.decode('utf-8')) for i in items]
+        return [int(i.decode("utf-8")) for i in items]
